@@ -16,8 +16,6 @@ except ImportError:
 
 import math
 
-    
-
 class Fisica(object):
     "Representa un simulador de mundo fisico, usando la biblioteca box2d."
     
@@ -38,6 +36,7 @@ class Fisica(object):
             self.mundo = None
             return
 
+        self.constante_mouse = None
         self.i = 0
         self.crear_bordes_del_escenario()
         self.figuras_a_eliminar = []
@@ -50,7 +49,23 @@ class Fisica(object):
     def reiniciar(self):
         for x in self.mundo.bodyList:
             self.mundo.DestroyBody(x)
+
         self.crear_bordes_del_escenario()
+
+    def capturar_figura_con_el_mouse(self, figura):
+        if self.constante_mouse:
+            self.cuando_suelta_el_mouse()
+        
+        self.constante_mouse = ConstanteDeMovimiento(figura)
+    
+    def cuando_mueve_el_mouse(self, x, y):
+        if self.constante_mouse:
+            self.constante_mouse.mover(x, y)
+
+    def cuando_suelta_el_mouse(self):
+        if self.constante_mouse:
+            self.constante_mouse.eliminar()
+            self.constante_mouse = None
         
     def actualizar(self):
         if self.mundo:
@@ -67,7 +82,6 @@ class Fisica(object):
                     self.mundo.DestroyBody(x)
             self.figuras_a_eliminar = []
 
-        
     def dibujar_figuras_sobre_lienzo(self, motor, lienzo, grosor=1):
         "Dibuja todas las figuras en una pizarra. Indicado para depuracion."
         cuerpos = self.mundo.bodyList
@@ -206,18 +220,30 @@ class Figura(object):
         velocidad = self._cuerpo.GetLinearVelocity()
         return (velocidad.x, velocidad.y)
 
-    def definir_velocidad_lineal(self, dx, dy):
+    def detener(self):
+        """Hace que la figura regrese al reposo."""
+        self.definir_velocidad_lineal(0, 0)
+
+    def definir_velocidad_lineal(self, dx=None, dy=None):
+        anterior_dx, anterior_dy = self.obtener_velocidad_lineal()
+
+        if dx is None:
+            dx = anterior_dx
+        if dy is None:
+            dy = anterior_dy
+
         self._cuerpo.SetLinearVelocity((dx, dy))
 
-    def empujar(self, dx, dy):
+    def empujar(self, dx=None, dy=None):
         self.definir_velocidad_lineal(dx, dy)
         
     def eliminar(self):
+        """Quita una figura de la simulación."""
         pilas.mundo.fisica.eliminar_figura(self._cuerpo)
         
-    x = property(obtener_x, definir_x)
-    y = property(obtener_y, definir_y)
-    rotacion = property(obtener_rotacion, definir_rotacion)
+    x = property(obtener_x, definir_x, doc="define la posición horizontal.")
+    y = property(obtener_y, definir_y, doc="define la posición vertical.")
+    rotacion = property(obtener_rotacion, definir_rotacion, doc="define la rotacion.")
     
 class Circulo(Figura):
     "Representa un cuerpo de circulo."
@@ -255,7 +281,6 @@ class Circulo(Figura):
         self._cuerpo = body
 
 class Rectangulo(Figura):
-    
     def __init__(self, x, y, ancho, alto, dinamica=True, densidad=1.0, 
             restitucion=0.56, friccion=10.5, amortiguacion=0.1, 
             fisica=None):
@@ -290,8 +315,44 @@ class Rectangulo(Figura):
 
         self._cuerpo = body
 
+class ConstanteDeMovimiento():
+
+    def __init__(self, figura):
+        md = box2d.b2MouseJointDef()
+        mundo = pilas.mundo.fisica.mundo
+        md.body1 = mundo.GetGroundBody()
+        md.body2 = figura._cuerpo
+        md.target = (figura.x, figura.y)
+        md.maxForce = 5000.0 * figura._cuerpo.GetMass()
+
+        try:
+            self.constante = mundo.CreateJoint(md).getAsType()
+        except:
+            self.constante = mundo.CreateJoint(md)
+
+        figura._cuerpo.WakeUp()
+
+    def mover(self, x, y):
+        self.constante.SetTarget((x, y))
+
+    def eliminar(self):
+        pilas.mundo.fisica.mundo.DestroyJoint(self.constante)
+
 class ConstanteDeDistancia():
-    
+    """Representa una distancia fija entre dos figuras.
+
+    Esta constante es útil para representar ejes o barras
+    que sostienen dos cuerpos. Por ejemplo, un eje entre dos
+    ruedas en un automóvil:
+
+        >>> circulo_1 = pilas.fisica.Circulo(-100, 0, 50)
+        >>> circulo_2 = pilas.fisica.Circulo(100, 50, 50)
+        >>> barra = pilas.fisica.ConstanteDeDistancia(circulo_1, circulo_2)
+
+    La distancia que tiene que respetarse en la misma que tienen
+    las figuras en el momento en que se establece la constante.
+    """
+
     def __init__(self, figura_1, figura_2, fisica=None):
         if not fisica:
             fisica = pilas.mundo.fisica
@@ -302,8 +363,11 @@ class ConstanteDeDistancia():
         constante = box2d.b2DistanceJointDef()
         constante.Initialize(figura_1._cuerpo, figura_2._cuerpo, (0,0), (0,0))
         constante.collideConnected = True
-        fisica.mundo.CreateJoint(constante)
+        self.constante = fisica.mundo.CreateJoint(constante)
 
 
+    def eliminar(self):
+        pilas.mundo.fisica.mundo.DestroyJoint(self.constante_mouse)
+
 def definir_gravedad(x=0, y=-90):
     pilas.mundo.fisica.mundo.gravity = (x, y)
