@@ -8,7 +8,6 @@
 
 import pilas
 import os
-import cairo
 
 def cargar(ruta):
     """Intenta cargar la imagen indicada por el argumento ``ruta``.
@@ -31,17 +30,13 @@ def cargar(ruta):
     En caso de error genera una excepción de tipo IOError.
     """
 
-    if not pilas.motor:
+    if not pilas.mundo:
         mensaje = "Tiene que invocar a la funcion ``pilas.iniciar()`` para comenzar."
         print mensaje
         raise Exception(mensaje)
     
     ruta = pilas.utils.obtener_ruta_al_recurso(ruta)
-    return pilas.motor.cargar_imagen(ruta)
-
-def cargar_imagen_cairo(ruta):
-    ruta = pilas.utils.obtener_ruta_al_recurso(ruta)
-    return cairo.ImageSurface.create_from_png(ruta)
+    return pilas.mundo.motor.cargar_imagen(ruta)
 
 def cargar_grilla(ruta, columnas=1, filas=1):
     """Representa una grilla de imagenes con varios cuadros de animación.
@@ -64,17 +59,19 @@ def cargar_grilla(ruta, columnas=1, filas=1):
         grilla.avanzar()
         grilla.asignar(actor)
     """
-    return pilas.motor.obtener_grilla(ruta, columnas, filas)
-
-def cargar_lienzo(ancho=640, alto=480):
-    """Representa un rectangulo (inicialmente transparente) para dibujar.
+    if not pilas.mundo:
+        mensaje = "Tiene que invocar a la funcion ``pilas.iniciar()`` para comenzar."
+        print mensaje
+        raise Exception(mensaje)
     
-    Internamente el lienzo tiene un contexto cairo, lo que permite
-    realizar dibujos vectoriales avanzados.
-    
-    Generalmente este objeto se utiliza usando al actor Pizarra.
-    """
-    return pilas.lienzo.Lienzo(ancho, alto)
+    ruta = pilas.utils.obtener_ruta_al_recurso(ruta)
+    return pilas.mundo.motor.obtener_grilla(ruta, columnas, filas)
 
-# Pronto en desuso
-# Grilla = pilas.motor.Grilla
+def cargar_lienzo():
+    """Representa un rectangulo (inicialmente transparente) para dibujar."""
+    return pilas.mundo.motor.obtener_lienzo()
+
+def cargar_superficie(ancho, alto):
+    return pilas.mundo.motor.obtener_superficie(ancho, alto)
+    
+cargar_imagen = cargar
